@@ -2,6 +2,7 @@ from __future__ import annotations
 
 from pylav.filters.channel_mix import ChannelMix
 from pylav.filters.distortion import Distortion
+from pylav.filters.echo import Echo
 from pylav.filters.equalizer import Equalizer
 from pylav.filters.karaoke import Karaoke
 from pylav.filters.lowpass import LowPass
@@ -10,4 +11,15 @@ from pylav.filters.timescale import Timescale
 from pylav.filters.vibrato import Vibrato
 from pylav.filters.volume import Volume
 
-__all__ = ("ChannelMix", "Distortion", "Equalizer", "Karaoke", "LowPass", "Rotation", "Timescale", "Vibrato", "Volume")
+__all__ = (
+    "ChannelMix",
+    "Distortion",
+    "Equalizer",
+    "Karaoke",
+    "LowPass",
+    "Rotation",
+    "Timescale",
+    "Vibrato",
+    "Volume",
+    "Echo",
+)
